/**
 * The MIT License
 * Copyright © 2016 Pascal Weyprecht
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package de.fxworld.systeminforest;

import io.vertx.core.AbstractVerticle;
import io.vertx.core.Launcher;
import io.vertx.ext.web.Router;
import io.vertx.ext.web.RoutingContext;
import io.vertx.ext.web.handler.BodyHandler;
import oshi.json.SystemInfo;

public class SystemInfoRest extends AbstractVerticle {

	private SystemInfo systemInfo;
	
	// Convenience method so you can run it in your IDE
	public static void main(String[] args) {
		Launcher.executeCommand("run", SystemInfoRest.class.getName());
	}

	@Override
	public void start() {
		Router router = Router.router(vertx);
		
		router.route().handler(BodyHandler.create());
		router.get("/").handler(this::handleGetSystemInfo);

		systemInfo = new SystemInfo();
		
		vertx.createHttpServer()
			.requestHandler(router::accept)
			.listen(config().getInteger("http.port", 4000));
	}
	
	private void handleGetSystemInfo(RoutingContext routingContext) {		
		vertx.<String>executeBlocking(
			future -> future.complete(systemInfo.toPrettyJSON()), 
			result -> routingContext.response()
				.putHeader("content-type", "application/json")
				.end(result.result())			
		);
	}
}
